<<<<<<< HEAD
# Fast_Starter
a fast api project structurer
=======
# Fast Starter

A simple package to quickly set up a FastAPI project structure.

## Installation

You can install the package via pip:

```bash
pip install fast_starter
>>>>>>> 475bd97 (Initial commit)
